@@ -9,7 +9,7 @@ from .exceptions import (
     PGSettingsNotFoundError,
 )
 from .resources import load_file_resource, load_text_resource
-from .util import delete_key, get_full_path, get_key, set_key
+from .util import delete_key, format_dict, get_full_path, get_key, set_key
 
 
 def load_json(name, input):
@@ -20,6 +20,14 @@ def load_json(name, input):
         raise PGJSONFormatError(name, str(err))
 
 
+def format_config(config, args):
+    """Formats the keys and values of a configuration."""
+    format_map = {
+        "name": args.name,
+    }
+    return format_dict(config, format_map)
+
+
 def get_playground_dir(args):
     """Retrieves the playground directory from args."""
     playground_dir = get_full_path(args.name)
@@ -79,7 +87,7 @@ def clean_config_new(args, raw_config):
         raise PGInvalidConfError(args.type)
     try:
         lib = type_config["lib"] + args.lib
-        return {
+        cleaned = {
             "dir": get_full_path(args.name),
             "verbosity": args.verbose,
             "folders": type_config["folders"] + ["requirements"],
@@ -97,6 +105,7 @@ def clean_config_new(args, raw_config):
         keys = (args.type, *err.args)
         key = ".".join(keys)
         raise PGInvalidConfError(key)
+    return format_config(cleaned, args)
 
 
 def clean_config_run(args):
@@ -125,29 +134,13 @@ def clean_config_config(args, raw_config):
     """Cleans the configuration for the config command."""
     new_config = raw_config
     subcommands = {
-        "add": clean_config_conf_add,
         "delete": clean_config_conf_delete,
-        "edit": clean_config_conf_edit,
+        "set": clean_config_conf_set,
     }
     func = subcommands.get(args.subcommand, clean_config_conf_read)
     return func(args, new_config)
 
 
-def clean_config_conf_add(args, config):
-    """Cleans the configuration for the config add command."""
-    cleaned = config
-    if args.type:
-        cleaned[args.type] = {}
-        if args.value:
-            cleaned[args.type] = load_json("input", args.value)
-    elif args.file:
-        file_path = get_full_path(args.file)
-        with open(file_path) as f:
-            custom_config = load_json(file_path, f.read())
-        cleaned.update(custom_config)
-    return cleaned
-
-
 def clean_config_conf_delete(args, config):
     """Cleans the configuration for the config delete command."""
     cleaned = config
@@ -166,12 +159,18 @@ def clean_config_conf_delete(args, config):
     return cleaned
 
 
-def clean_config_conf_edit(args, config):
-    """Cleans the configuration for the config edit command."""
+def clean_config_conf_set(args, config):
+    """Cleans the configuration for the config set command."""
     cleaned = config
-    keys = args.key.split(".")
-    value = load_json("input", args.value)
-    set_key(keys, value, cleaned)
+    if args.key:
+        keys = args.key.split(".")
+        value = load_json("input", args.value)
+        set_key(keys, value, cleaned)
+    elif args.file:
+        file_path = get_full_path(args.file)
+        with open(file_path) as f:
+            custom_config = load_json(file_path, f.read())
+        cleaned.update(custom_config)
     return cleaned
 
 
